#!/usr/bin/env bash

# become admin user
source ~/chrisjrc

cd ~/

# upload images
openstack image create --disk-format raw --file /mnt/bigmomma/nfsshare/rhel-guest-image-7.2.raw --public --container-format bare --property os_type=linux --property os_distro=rhel7.2 --property hw_scsi_model=virtio-scsi --property hw_disk_bus=scsi rhel7-raw

openstack image create --disk-format raw --file /mnt/bigmomma/nfsshare/cirros-0.3.4-x86_64-disk.raw --public --container-format bare --property os_type=linux --property hw_scsi_model=virtio-scsi --property hw_disk_bus=scsi cirros

#openstack image create --disk-format raw --file /mnt/bigmomma/nfsshare/pxeboot.img --public --container-format bare --property os_type=linux --property os_distro=rhel7.2 --property hw_scsi_model=virtio-scsi --property hw_disk_bus=scsi pxeboot

# Create external Networks

neutron net-create external --router:external=true --provider:physical_network=fast \
    --provider:network_type=vlan --provider:segmentation_id=318 --shared
neutron subnet-create external 172.31.8.0/24 \
    --name public_subnet-int --allocation-pool \
    start=172.31.8.150,end=172.31.8.199 --gateway 172.31.8.254 --dns-nameserver 172.31.8.1



#neutron net-create provider1 --router:external=true --provider:physical_network=fast \
#    --provider:network_type=vlan --provider:segmentation_id=316 --shared
#neutron subnet-create provider1 172.31.6.0/24 \
#    --name provider-sub1 --allocation-pool \
#    start=172.31.6.10,end=172.31.6.199 --gateway 172.31.6.254 --dns-nameserver 172.31.8.1



neutron net-create provider1 --provider:physical_network=fast \
    --provider:network_type=vlan --provider:segmentation_id=316 --shared
neutron subnet-create provider1 172.31.6.0/24 \
    --name provider-sub1 --allocation-pool \
    start=172.31.6.10,end=172.31.6.199 --gateway 172.31.6.254 --dns-nameserver 172.31.8.1

neutron net-create provider2  --router:external=true --provider:physical_network=fast \
    --provider:network_type=vlan --provider:segmentation_id=315 --shared
neutron subnet-create provider2 172.31.5.0/24 \
    --name provider-sub2 --allocation-pool \
    start=172.31.5.10,end=172.31.5.199 --gateway 172.31.5.254 --dns-nameserver 172.31.8.1

neutron net-create baremetal  --provider:physical_network=fast \
    --provider:network_type=vlan --provider:segmentation_id=320 --shared
neutron subnet-create baremetal 172.31.10.0/24 \
    --name baremetal-sub --allocation-pool \
    start=172.31.10.10,end=172.31.10.199 --gateway 172.31.10.254 --dns-nameserver 172.31.8.1



#create flavors
#openstack flavor create --ram 16384 --disk 100 --vcpu 4 --public undercloud
#openstack flavor create --ram 12288 --disk 60 --vcpu 2 --public overcloud-controller
#openstack flavor create --ram 12288 --disk 60 --vcpu 4 --public overcloud-compute
#openstack flavor create --ram 16384 --disk 50 --vcpu 4 --public overcloud-hci
#openstack flavor create --ram 4096 --disk 50 --vcpu 2 --public overcloud-ceph
openstack flavor create --ram 2048 --disk 10 --vcpu 1 --public small
openstack flavor create --ram 4096 --disk 20 --vcpu 2 --public medium
openstack flavor create --ram 8192 --disk 40 --vcpu 4 --public large


# create test tenant
openstack project create --description "Demo Tenant1" --enable tenant1
openstack user create  --project tenant1 --password Passw0rd tenant1
cp ~/chrisjrc ~/tenant1rc
sed -i 's/admin/tenant1/g' ~/tenant1rc
sed -i 's/OS_PASSWORD.*/OS_PASSWORD=Passw0rd/g' ~/tenant1rc

#change to tenant1 credentials
source ~/tenant1rc

#create tenant1 network
neutron net-create tenant1-net1
neutron subnet-create tenant1-net1 192.168.100.0/24 --name tenant1-subnet1 --dns-nameserver 192.168.1.254
neutron router-create tenant1-router1
neutron router-gateway-set tenant1-router1 external1
neutron router-interface-add tenant1-router1 tenant1-subnet1



# Create security groups
nova secgroup-add-rule default tcp 22 22 0.0.0.0/0
nova secgroup-add-rule default icmp -1 -1 0.0.0.0/0

#add ssh key
nova keypair-add --pub-key ~/.ssh/id_rsa.pub undercloud-key



# Boot test image
nova boot --flavor small --image rhel7-raw --key-name undercloud-key tenant1-test1
neutron floatingip-create external1


